"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateSchemas = void 0;
const case_1 = __importDefault(require("case"));
const lodash_1 = __importDefault(require("lodash"));
const { isEmpty } = lodash_1.default;
const { pascal } = case_1.default;
const utils_js_1 = require("./utils.js");
const utils_js_2 = require("./utils.js");
/**
 * Generate the interface string
 */
const generateInterface = (name, schema) => {
    const scalar = (0, utils_js_1.getScalar)(schema);
    return `
       ${(0, utils_js_1.formatDescription)(schema.description)}
       export type ${pascal(name)} = ${scalar}
     `;
};
/**
 * Extract all types from #/components/schemas
 */
const generateSchemasDefinition = (schemas = {}) => {
    if (isEmpty(schemas)) {
        return '';
    }
    return ('\n // SCEHMAS \n' +
        Object.entries(schemas)
            .map(([name, schema]) => !(0, utils_js_1.isReference)(schema) &&
            (!schema.type || schema.type === 'object') &&
            !schema.allOf &&
            !schema.oneOf &&
            !(0, utils_js_1.isReference)(schema) &&
            !schema.nullable
            ? generateInterface(name, schema)
            : `${(0, utils_js_1.formatDescription)((0, utils_js_1.isReference)(schema) ? undefined : schema.description)} export type ${pascal(name)} = ${(0, utils_js_1.resolveValue)(schema)};`)
            .join('\n\n') +
        '\n');
};
/**
 * Extract all types from #/components/requestBodies
 */
const generateRequestBodiesDefinition = (requestBodies = {}) => {
    if (isEmpty(requestBodies)) {
        return '';
    }
    return ('\n // REQUEST BODIES \n' +
        Object.entries(requestBodies)
            .map(([name, requestBody]) => {
            const doc = (0, utils_js_2.getDocs)(requestBody);
            const type = (0, utils_js_2.getResReqTypes)([['', requestBody]]);
            const isEmptyInterface = type === '{}';
            if (isEmptyInterface) {
                return `${doc}export type ${pascal(name)}RequestBody = ${type}`;
            }
            else if (type.includes('{') && !type.includes('|') && !type.includes('&')) {
                return `${doc}export type ${pascal(name)}RequestBody = ${type}`;
            }
            else {
                return `${doc}export type ${pascal(name)}RequestBody = ${type};`;
            }
        })
            .join('\n\n') +
        '\n');
};
/**
 * Extract all types from #/components/responses
 */
const generateResponsesDefinition = (responses = {}) => {
    if (isEmpty(responses)) {
        return '';
    }
    return ('\n // RESPONSES \n' +
        Object.entries(responses)
            .map(([name, response]) => {
            const doc = (0, utils_js_2.getDocs)(response);
            const type = (0, utils_js_2.getResReqTypes)([['', response]]);
            const isEmptyInterface = type === '{}';
            if (isEmptyInterface) {
                return `export type RQ${pascal(name)}Response = ${type}`;
            }
            else if (type.includes('{') && !type.includes('|') && !type.includes('&')) {
                return `${doc}export type RQ${pascal(name)}Response = ${type}`;
            }
            else {
                return `${doc}export type RQ${pascal(name)}Response = ${type};`;
            }
        })
            .join('\n\n') +
        '\n');
};
/**
 * Extract all types from #/components/schemas
 */
const generateSchemas = ({ spec }) => {
    const schemaOutput = generateSchemasDefinition(spec.components?.schemas) +
        generateResponsesDefinition(spec.components?.responses) +
        generateRequestBodiesDefinition(spec.components?.requestBodies);
    return schemaOutput;
};
exports.generateSchemas = generateSchemas;
