"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.importSpecs = void 0;
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = require("fs");
const path_1 = require("path");
const convertSwaggerFile_js_1 = require("./convertSwaggerFile.js");
const generateHooks_js_1 = require("./generateHooks.js");
const generateSchemas_js_1 = require("./generateSchemas.js");
function importSpecs({ sourceDirectory, exportDirectory, apiDirectory, queryClientDir, headerFilters, }) {
    (0, fs_1.readdir)(sourceDirectory, function (err, filenames) {
        if (err) {
            console.log(err);
            throw err;
        }
        filenames.map(async (filename) => {
            try {
                const data = (0, fs_1.readFileSync)((0, path_1.join)(process.cwd(), sourceDirectory + '/' + filename), 'utf-8');
                const { ext } = (0, path_1.parse)(sourceDirectory + '/' + filename);
                const format = ['.yaml', '.yml'].includes(ext.toLowerCase()) ? 'yaml' : 'json';
                const name = filename.split('.')[0];
                let spec = await (0, convertSwaggerFile_js_1.convertSwaggerFile)(data, format);
                const operationIds = [];
                (0, fs_1.mkdirSync)((0, path_1.join)(process.cwd(), `${exportDirectory}/${name}`), { recursive: true });
                const { implementation, schemaImports } = (0, generateHooks_js_1.generateQueryHooks)({ spec, operationIds, headerFilters });
                const schemaName = `useQueries${filename.split('.')[0]}.schema`;
                const imports = (0, generateHooks_js_1.generateImports)({ apiDirectory, queryClientDir, schemaName, schemaImports });
                const hooksName = `useQueries${filename.split('.')[0]}`;
                (0, fs_1.writeFileSync)((0, path_1.join)(process.cwd(), `${exportDirectory}/${name}/${hooksName}.tsx`), imports + implementation);
                const schemas = (0, generateSchemas_js_1.generateSchemas)({ spec });
                (0, fs_1.writeFileSync)((0, path_1.join)(process.cwd(), `${exportDirectory}/${name}/${schemaName}.tsx`), schemas);
                console.log(chalk_1.default.green(`🎉 [${filename}] Your OpenAPI spec has been converted into react query hooks`));
            }
            catch (error) {
                if (error.code === 'EISDIR') {
                    return;
                }
                console.log(chalk_1.default.red(`[${filename}]:`), chalk_1.default.red(error));
            }
        });
    });
}
exports.importSpecs = importSpecs;
