import chalk from 'chalk';
import { readFileSync, writeFileSync, readdir, mkdirSync } from 'fs';
import { join, parse } from 'path';
import { convertSwaggerFile } from './convertSwaggerFile.js';
import { generateImports, generateQueryHooks } from './generateHooks.js';
import { generateSchemas } from './generateSchemas.js';
export function importSpecs({ sourceDirectory, exportDirectory, apiDirectory, queryClientDir, headerFilters, }) {
    readdir(sourceDirectory, function (err, filenames) {
        if (err) {
            console.log(err);
            throw err;
        }
        filenames.map(async (filename) => {
            try {
                const data = readFileSync(join(process.cwd(), sourceDirectory + '/' + filename), 'utf-8');
                const { ext } = parse(sourceDirectory + '/' + filename);
                const format = ['.yaml', '.yml'].includes(ext.toLowerCase()) ? 'yaml' : 'json';
                const name = filename.split('.')[0];
                let spec = await convertSwaggerFile(data, format);
                const operationIds = [];
                mkdirSync(join(process.cwd(), `${exportDirectory}/${name}`), { recursive: true });
                const { implementation, schemaImports } = generateQueryHooks({ spec, operationIds, headerFilters });
                const schemaName = `useQueries${filename.split('.')[0]}.schema`;
                const imports = generateImports({ apiDirectory, queryClientDir, schemaName, schemaImports });
                const hooksName = `useQueries${filename.split('.')[0]}`;
                writeFileSync(join(process.cwd(), `${exportDirectory}/${name}/${hooksName}.tsx`), imports + implementation);
                const schemas = generateSchemas({ spec });
                writeFileSync(join(process.cwd(), `${exportDirectory}/${name}/${schemaName}.tsx`), schemas);
                console.log(chalk.green(`🎉 [${filename}] Your OpenAPI spec has been converted into react query hooks`));
            }
            catch (error) {
                if (error.code === 'EISDIR') {
                    return;
                }
                console.log(chalk.red(`[${filename}]:`), chalk.red(error));
            }
        });
    });
}
